@@ -549,8 +549,7 @@ class Endpoints:
 
         @v1.route("/connection/test", methods=["POST"])
         def connection_test():
-            """THIS ENDPOINT IS NOT IN USE AS IT DOES NOT GET INITIALIZED IN THE CONNECTION
-            The "/actions/<string:name>/test" endpoint is currently being used for connection tests
+            """
             Run connection test endpoint
             ---
             post:
@@ -566,31 +565,29 @@ class Endpoints:
                   description: A ConnectionTestException has occurred
                 500:
                   description: Internal server error
+                501:
+                  description: The connection test() is not implmented
             """
             status_code = 200
-            message = None
-            try:
-                if hasattr(self.plugin.connection, "test"):
-                    response = self.plugin.connection.test()
-                    if response is None:
-                        status_code = 204
-                        message = "The server successfully processed the request and is not returning any content"
-                    else:
-                        message = response
-                else:
-                    status_code = 204
-                    message = "The server successfully processed the request and is not returning any content"
-            except Exception as e:
-                if isinstance(e, ConnectionTestException):
-                    status_code = 400
-                    message = e.data
-                else:
-                    status_code = 500
-                    message = str(e)
-            finally:
-                output = make_response(jsonify({"message": message}), status_code)
-                return output
+            output = None
 
+            input_message = request.get_json(force=True)
+            Endpoints.validate_action_trigger_task_empty_input(input_message)
+
+            try:
+                output = self.plugin.handle_step(input_message, is_debug=self.debug, is_test=True)
+                if output.get("body", {}).get("output") is None:
+                    status_code = 204
+            except LoggedException as e:
+                wrapped_exception = e.ex
+                self.logger.exception(wrapped_exception)
+
+                output = e.output
+                status_code = Endpoints.handle_wrapped_exception(wrapped_exception)
+            finally:
+                r = jsonify(output)
+                r.status_code = status_code
+                return r
         blueprints = [legacy, v1]
         return blueprints
 
@@ -690,3 +687,17 @@ class Endpoints:
             r = jsonify(output)
             r.status_code = status_code
             return r
+
+    @staticmethod
+    def handle_wrapped_exception(wrapped_exception):
+        if isinstance(wrapped_exception, (ConnectionTestException, ClientException)):
+            return 400
+        elif isinstance(wrapped_exception, PluginException):
+            if wrapped_exception.preset is PluginException.Preset.BAD_REQUEST:
+                return 400
+        elif isinstance(wrapped_exception, ServerException):
+            return 500
+        elif isinstance(wrapped_exception, NotImplementedError):
+            return 501
+        else:
+            return 500
